@@ -27,8 +27,8 @@ gnome_voice_file_parser (VoiceInfo *info,
 		if ((!xmlStrcmp (sub->name, (const xmlChar *) "location"))) {
 			LocationInfo *location = g_new0 (LocationInfo, 1);
 			info->location = location;
-			info->location->city = (gchar *) xmlNodeListGetString (sub, sub->xmlChildrenNode, 1);
-			g_print ("location:city:%s\n", info->location->city);
+			info->location->code = (gchar *) xmlNodeListGetString (sub, sub->xmlChildrenNode, 1);
+			g_print ("location:code:%s\n", info->location->code);
 			info->location->lat = (gdouble *)xmlGetProp(sub, (const xmlChar *)"lat");
 			g_print ("location:lat:%s\n", info->location->lat);
 			info->location->lon = (gdouble *)xmlGetProp(sub, (const xmlChar *)"lon");
