@@ -31,7 +31,7 @@ struct _VoiceWindow {
 struct _LocationInfo {
         gdouble *lat;
 	gdouble *lon;
-	gchar *city;
+	gchar *code;
 };
 
 struct _VoiceInfo {
