@@ -13,8 +13,6 @@
 #include <geoclue.h>
 #include <champlain-gtk/champlain-gtk.h>
 #include <clutter-gtk/clutter-gtk.h>
-#include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 
@@ -91,7 +89,7 @@ create_marker_layer (G_GNUC_UNUSED ChamplainView *view, ChamplainPathLayer **pat
 	ClutterActor *marker;
 	ClutterActor *layer_actor;
 	ChamplainLabel *self;
-	ClutterColor code_color = { 0xa5, 0x6d, 0xe2, 0xbb };
+	ClutterColor code_color = { 0x9a, 0x9b, 0x9c, 0x9d };
 	ClutterColor voicegram_color = { 0x6d, 0xa5, 0xe2, 0xbb };
 	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
 	LocationCallbackData callback_data;
@@ -252,7 +250,7 @@ static GOptionEntry entries[] =
           &accuracy_level,
           N_("Request accuracy level A. "
              "Country = 1, "
-             "Code = 4, "
+             "City = 4, "
              "Neighborhood = 5, "
              "Street = 6, "
              "Exact = 8."),
@@ -269,7 +267,7 @@ static GOptionEntry entries[] =
 	  0,
 	  G_OPTION_ARG_STRING,
 	  &voice_stream,
-	  N_("Stream.  Default: https://api.perceptron.stream:8000/128.ogg"),
+	  N_("Stream.  Default: https://api.perceptron.stream:8000/56.ogg"),
 	  "S" },
         { NULL }
 };
@@ -478,7 +476,7 @@ gps_callback (GClueSimple *simple, GpsCallbackData *data)
 
         GError **error = NULL;
 	gdouble lat, lon;
-	ClutterColor code_color = { 0x9a, 0x9b, 0x9c, 0x9d };
+	ClutterColor code_color = { 0xa5, 0x6d, 0xe2, 0xbb };
 	ClutterColor text_color = { 0xff, 0xff, 0xff, 0xff };
 	const char *name, *name_code, *name_country;
 	/* GeocodeForward *fwd; */
@@ -543,11 +541,10 @@ static void gv_wizard_button_clicked(GtkButton * button,
 	muxer = gst_element_factory_make("oggmux", "oggmux");
 	sink = gst_element_factory_make("filesink", "sink");
 	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/",
-			       "GNOME.ogg", NULL);
+ 			       "GNOME.ogg", NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/",
-				 g_get_user_name(), ".ogg", NULL), NULL);
-	g_object_set(G_OBJECT(enc), "quality", 1.0);
+				 g_get_user_name(), ".ogg", NULL), NULL);		g_object_set(G_OBJECT(enc), "quality", 1.0);
 	gst_bin_add_many(GST_BIN(recorder), src, conv, enc, muxer, sink, NULL);
 	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
 	gst_element_set_state(recorder, GST_STATE_PLAYING);
@@ -557,7 +554,7 @@ static void gv_wizard_button_clicked(GtkButton * button,
                                  GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(title_entry)),
                                  GST_TAG_ARTIST, g_get_real_name(),
                                  GST_TAG_ALBUM, "Voicegrams",
-                                 GST_TAG_COMMENT, "GNOME 45",
+                                 GST_TAG_COMMENT, "GNOME 46",
                                  GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
                                  NULL);
 	g_date_time_unref (datestamp);
@@ -569,6 +566,7 @@ static void gv_wizard_button_clicked(GtkButton * button,
 	g_date_time_unref (datestamp);
 }
 
+
 static void gv_wizard_cancel(GtkAssistant * assistant, gpointer data)
 {
 	if (!main_loops) {
@@ -595,66 +593,31 @@ static void gv_wizard_close(GtkAssistant * assistant, gpointer data)
 	gchar *string;
 	const char *charset;
 	guint status;
-	GUri *uri;
-	GCancellable *cancellable;
-	
+	GError *error = NULL;
+	GBytes *bytes;
 	gchar *voicegram_save_url;
 	voiceinfo = (VoiceInfo *) data;
 	/* Geographical Position System Location. */
 	/* lat_gps = gclue_location_get_latitude (location); */
 	/* lon_gps = gclue_location_get_longitude (location); */
 	/* Version and current date. */
-	/*
-	SoupSession *session = soup_session_new ();
-	SoupMessageHeaders *response_headers;
-	const char *content_type;
-	GError *error = NULL;
-	GBytes *bytes;
-	GHashTable **params;
 	t_timebuffer = g_date_time_new_now_utc ();
 	g_date_clear (&d, 1);
 	g_date_set_time_t (&d, time (NULL));
 	g_date_strftime (timebuffer, sizeof (timebuffer), "%s", &d);
-	*/
 	voice_pointer = fopen(filename_voice, "w");
 	fprintf(voice_pointer, "<voice version='%s'>\n", VERSION);
-	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/~%s/%s.ogg'>\n",
+	fprintf(voice_pointer, "  <station name='%s' uri='http://%s/GNOME.ogg'>\n",
 		g_get_real_name(),
-		g_get_host_name(),
-		g_get_user_name(),
-		g_get_user_name());
-	fprintf(voice_pointer, "    <location lat='%9.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
-	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", g_get_user_name(), ".voice");
+		g_get_host_name());
+	fprintf(voice_pointer, "    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name());
+	fprintf(voice_pointer, "    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice");
 	fprintf(voice_pointer, "  </station>\n");
 	fprintf(voice_pointer, "</voice>\n");
 	fclose(voice_pointer);
 	voicegram_save_url = g_strconcat(g_strconcat("https://www.gnomevoice.org/stream/?notBefore=", g_date_time_format_iso8601 (t_timebuffer), NULL), g_strconcat("&notAfter=",g_date_time_format_iso8601 (t_timebuffer), "&label=GNOME&sofset=0&eofset=", NULL), g_strconcat(strlen(voice_pointer), "&MAX_FILE_SIZE=5000000&userfile=", filename_voice, NULL));
-        g_print ("voicegram:url:%s\n", voicegram_save_url);
-        /*
-        msg = soup_message_new ("POST", voicegram_save_url);
-	response_headers = soup_message_get_response_headers (msg);
-	content_type = soup_message_headers_get_content_type (response_headers, params);
-	soup_message_set_request_body (msg, "application/xml",
-				       g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
-					      g_strconcat("  <station name='", g_get_user_name(), "' uri='http://", g_get_host_name(), "/GNOME.voice'>\n", NULL),
-					      g_strconcat("    <location lat='%10.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
-					      g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
-					      g_strconcat("  </station>\n", NULL),
-					      g_strconcat("</voice>\n", NULL),NULL),
-				  strlen(g_strconcat(g_strconcat("<voice version='", VERSION, "'>\n", NULL),
-						     g_strconcat("  <station name='", g_get_user_name(), "' uri='http://", g_get_host_name(), "/GNOME.voice'>\n", NULL),
-						     g_strconcat("    <location lat='%9.7f' lon='%9.7f'>%s</location>\n", lat_gps, lon_gps, g_get_host_name(), NULL),
-						     g_strconcat("    <stream>https://www.gnomevoice.org/stream/data/%s%s</stream>\n", timebuffer, ".voice", NULL),
-						     g_strconcat("  </station>\n", NULL),
-						     g_strconcat("</voice>\n", NULL),NULL)));
-	status = soup_session_send (session, msg, cancellable, error);
-	g_bytes_unref (bytes);
-	g_object_unref (msg);
-	g_object_unref (session);
 	g_date_time_unref (datestamp);
-	*/
-
-    if (!main_loops) {
+	if (!main_loops) {
 	         g_error("Quit more loops than there are.");
         } else {
                 GMainLoop *loop = main_loops;
@@ -714,7 +677,7 @@ main (gint argc, gchar **argv)
 	GtkWidget *introduction;
 	int i = 0;
 	PageInfo page[5] = {
-		{NULL, -1, "Voice 5.0.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
+		{NULL, -1, "Voice 6.0.0", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Voicegram", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Filename", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Summary", GTK_ASSISTANT_PAGE_SUMMARY, TRUE},		
@@ -727,19 +690,18 @@ main (gint argc, gchar **argv)
 	GOptionContext *context;
 	GtkTextBuffer *buffer;
 	char *basename;
-	char *uri_href;
 	GtkWidget *scrolled, *textview;
 	char *contents;
 	gsize length;
 	
-	voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/", g_get_user_name(), ".voice", NULL);
+	voice_filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.voice", NULL);
 	voinfo = gnome_voice_file_loader (voinfo, voice_filename);
 	// gtk_init(&argc, &argv);
 	if (argc < 2) {
 	  fprintf(stderr, "No Voice Stream typed on the command line\n");
 	}
 
-	context = g_option_context_new ("- Voice 5.0.0");
+	context = g_option_context_new ("- Voice 6.0.0");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (!g_option_context_parse (context, &argc, &argv, &error)) {
@@ -752,15 +714,15 @@ main (gint argc, gchar **argv)
 	introduction = gtk_assistant_new();
 	gtk_container_add (GTK_WINDOW (window), introduction);
 	gtk_widget_set_size_request(GTK_WIDGET(introduction), 800, 600);
-	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 5.0.0");
+	gtk_window_set_title(GTK_WINDOW(introduction), "Voice 6.0.0");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
-	page[0].widget = gtk_label_new(_("Welcome to Voice 5.0.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
+	page[0].widget = gtk_label_new(_("Welcome to Voice 6.0.0!\n\nRecord respectfully around others.\n\nClick Next to setup a voice recording session!\n\nClick Cancel to stop the voice recording session.\n\nClick Cancel twice to exit Voice."));
 	page[1].widget = gtk_box_new(FALSE, 5);
 	title_label = gtk_label_new(_("Voicegram:"));
 	title_entry = gtk_entry_new();
 	gtk_entry_set_max_length (title_entry, 256);
-	if (g_strcmp0(title_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(title_entry), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/", g_get_user_name(), ".voice", NULL)); else gtk_entry_set_text(GTK_ENTRY(title_entry), gtk_entry_get_text(GTK_ENTRY(title_entry)));
+	if (g_strcmp0(title_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(title_entry), g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.voice", NULL)); else gtk_entry_set_text(GTK_ENTRY(title_entry), gtk_entry_get_text(GTK_ENTRY(title_entry)));
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(title_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(title_entry),
@@ -768,7 +730,7 @@ main (gint argc, gchar **argv)
 	page[2].widget = gtk_box_new(FALSE, 5);
 	filename_label = gtk_label_new(_("Filename:"));
 	filename_entry = gtk_entry_new();
-	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat (g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/", g_get_user_name(), ".ogg", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
+	if (g_strcmp0(filename_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(filename_entry), g_strconcat ("GNOME.ogg", NULL)); else gtk_entry_set_text(GTK_ENTRY(filename_entry), gtk_entry_get_text(GTK_ENTRY(filename_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(filename_entry),
@@ -820,9 +782,9 @@ main (gint argc, gchar **argv)
 	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
 	muxer = gst_element_factory_make("oggmux", "oggmux");
 	sink = gst_element_factory_make("filesink", "sink");
-	filename = g_strconcat("file://", g_get_host_name(), g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), gtk_entry_get_text(filename_entry), NULL);
+	filename = g_strconcat("file://", g_get_host_name(), g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), gtk_entry_get_text(filename_entry), NULL);
 	g_object_set(G_OBJECT(sink), "location",
-		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_DESKTOP), "/", gtk_entry_get_text(filename_entry), NULL));
+		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/", gtk_entry_get_text(filename_entry), NULL));
 	gst_bin_add_many(GST_BIN(pipeline), src, conv, enc, muxer, sink, NULL);
 	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
 
@@ -833,7 +795,7 @@ main (gint argc, gchar **argv)
 				 GST_TAG_TITLE, g_get_real_name(),
 				 GST_TAG_ARTIST, g_get_real_name(),
 				 GST_TAG_ALBUM, gtk_entry_get_text(filename_entry),
-				 GST_TAG_COMMENT, "Voice 5.0.0",
+				 GST_TAG_COMMENT, "Voice 6.0.0",
 				 GST_TAG_DATE, g_date_time_format_iso8601 (datestamp),
 				 NULL);
 	g_date_time_unref (datestamp);
